@@ -9,6 +9,9 @@
 #ifndef LIBC_BIONIC
 # define LIBC_BIONIC 3
 #endif
+#ifndef PIE_DEFAULT
+# define PIE_DEFAULT 2
+#endif
 #ifdef IN_GCC
 # include "options.h"
 # include "insn-constants.h"
@@ -21,9 +24,13 @@
 # include "config/rs6000/sysv4.h"
 # include "config/rs6000/openbsd.h"
 # include "config/rs6000/option-defaults.h"
+# include "config/initfini-array.h"
 #endif
 #if defined IN_GCC && !defined GENERATOR_FILE && !defined USED_FOR_TARGET
 # include "insn-flags.h"
 #endif
+#if defined IN_GCC && !defined GENERATOR_FILE
+# include "insn-modes.h"
+#endif
 # include "defaults.h"
 #endif /* GCC_TM_H */
